@@ -1,4 +1,4 @@
-use actix_web_v4::{web, App, Error, FromRequest, HttpResponse, HttpServer};
+use actix_web_v4::{web, App, Error, HttpResponse, HttpServer};
 
 pub async fn upload(parts: awmp::Parts) -> Result<HttpResponse, Error> {
     let qs = parts.texts.to_query_string();
@@ -25,7 +25,7 @@ pub async fn upload(parts: awmp::Parts) -> Result<HttpResponse, Error> {
 async fn main() -> Result<(), std::io::Error> {
     HttpServer::new(move || {
         App::new()
-            .data(awmp::PartsConfig::default().with_file_limit(100000))
+            .app_data(awmp::PartsConfig::default().with_file_limit(100000))
             .route("/", web::post().to(upload))
     })
     .bind("0.0.0.0:3000")?
